Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1508)

Unified Diff: chrome/browser/chromeos/policy/cloud_external_data_manager_base.h

Issue 1870793002: Convert //chrome/browser/chromeos from scoped_ptr to std::unique_ptr (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/policy/cloud_external_data_manager_base.h
diff --git a/chrome/browser/chromeos/policy/cloud_external_data_manager_base.h b/chrome/browser/chromeos/policy/cloud_external_data_manager_base.h
index ad48edf76c0b960664377580a1e50ac04043c1b5..ec078d40280c3dabff1a7b45753c6c4e137fd3b5 100644
--- a/chrome/browser/chromeos/policy/cloud_external_data_manager_base.h
+++ b/chrome/browser/chromeos/policy/cloud_external_data_manager_base.h
@@ -5,10 +5,11 @@
#ifndef CHROME_BROWSER_CHROMEOS_POLICY_CLOUD_EXTERNAL_DATA_MANAGER_BASE_H_
#define CHROME_BROWSER_CHROMEOS_POLICY_CLOUD_EXTERNAL_DATA_MANAGER_BASE_H_
+#include <memory>
+
#include "base/compiler_specific.h"
#include "base/macros.h"
#include "base/memory/ref_counted.h"
-#include "base/memory/scoped_ptr.h"
#include "base/threading/non_thread_safe.h"
#include "components/policy/core/common/cloud/cloud_external_data_manager.h"
#include "components/policy/core/common/policy_details.h"
@@ -41,10 +42,11 @@ class CloudExternalDataManagerBase : public CloudExternalDataManager,
// Allows downloaded external data to be cached in |external_data_store|.
// Ownership of the store is taken. The store can be destroyed by calling
// SetExternalDataStore(scoped_ptr<CloudExternalDataStore>()). Accesses to the
// store are made via |backend_task_runner_| only.
void SetExternalDataStore(
- scoped_ptr<CloudExternalDataStore> external_data_store);
+ std::unique_ptr<CloudExternalDataStore> external_data_store);
// CloudExternalDataManager:
void SetPolicyStore(CloudPolicyStore* policy_store) override;
@@ -78,7 +80,7 @@ class CloudExternalDataManagerBase : public CloudExternalDataManager,
// referenced from background threads. It is instantiated on the thread |this|
// runs on but after that, must only be accessed and eventually destroyed via
// the |io_task_runner_|.
- scoped_ptr<ExternalPolicyDataFetcherBackend>
+ std::unique_ptr<ExternalPolicyDataFetcherBackend>
external_policy_data_fetcher_backend_;
// The |backend_| handles all data download scheduling, verification, caching
@@ -86,7 +88,7 @@ class CloudExternalDataManagerBase : public CloudExternalDataManager,
// that, must only be accessed and eventually destroyed via the
// |backend_task_runner_|.
class Backend;
- scoped_ptr<Backend> backend_;
+ std::unique_ptr<Backend> backend_;
DISALLOW_COPY_AND_ASSIGN(CloudExternalDataManagerBase);
};
@@ -41,10 +42,11 @@ class CloudExternalDataManagerBase : public CloudExternalDataManager,
// Allows downloaded external data to be cached in |external_data_store|.
// Ownership of the store is taken. The store can be destroyed by calling
- // SetExternalDataStore(scoped_ptr<CloudExternalDataStore>()). Accesses to the
+ // SetExternalDataStore(std::unique_ptr<CloudExternalDataStore>()). Accesses
+ // to the
// store are made via |backend_task_runner_| only.
void SetExternalDataStore(

Powered by Google App Engine
This is Rietveld 408576698